@@ -381,11 +381,10 @@ def insert_from_json(file_name: str, table_name: str, encoding='utf-8') -> int:
 
 def truncate(table_name: str) -> int:
     """ sqlexec.truncate('person') """
-    return _execute('TRUNCATE TABLE %s' % table_name)
+    return _execute(Dialect.get_truncate_sql(table_name))
 
 
 def drop(table_name: str) -> int:
     """ sqlexec.drop('person') """
     return _execute('DROP TABLE %s' % table_name)
 
-
